@@ -30,9 +30,11 @@
 
 #include "kaffeinedvbsection.h"
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
-
-class ShortEvent
+class KDE_EXPORT ShortEvent
 {
 
 public:
@@ -44,7 +46,7 @@ public:
 	TQString text;
 };
 
-class EventDesc
+class KDE_EXPORT EventDesc
 {
 
 public:
@@ -72,7 +74,7 @@ public:
 
 
 
-class EventSid
+class KDE_EXPORT EventSid
 {
 public:
 	EventSid( int s );
@@ -92,7 +94,7 @@ private:
 
 
 
-class EventTsid
+class KDE_EXPORT EventTsid
 {
 public:
 	EventTsid( int n, int t );
@@ -111,7 +113,7 @@ private:
 
 
 
-class EventSource
+class KDE_EXPORT EventSource
 {
 public:
 	EventSource( TQString src );
@@ -129,7 +131,7 @@ private:
 
 
 
-class EventTable : public TQObject, public TQThread
+class KDE_EXPORT EventTable : public TQObject, public TQThread
 {
 	Q_OBJECT
   
